@@ -46,7 +46,7 @@ PD.age <- function(x,nuclide,exterr=TRUE,i=NA,sigdig=NA,i2i=TRUE,...){
         J[1,2] <- 1/dat[j,'X']        
         DP <- dat[j,'Y']/dat[j,'X']
         sDP <- sqrt(J%*%E%*%t(J))
-        tt <- get.PD.age(DP,sDP,nuclide,exterr=TRUE)
+        tt <- get.PD.age(DP,sDP,nuclide,exterr=exterr)
         out[j,] <- roundit(tt[1],tt[2],sigdig=sigdig)
     }
     if (!is.na(i)) out <- out[i,]
