@@ -50,6 +50,7 @@
 #' @rdname agespectrum
 #' @export
 agespectrum <- function(x,...){ UseMethod("agespectrum",x) }
+#' @importFrom grDevices rgb
 #' @rdname agespectrum
 #' @export
 agespectrum.default <- function(x,alpha=0.05,plateau=TRUE,
@@ -78,7 +79,7 @@ agespectrum.default <- function(x,alpha=0.05,plateau=TRUE,
         graphics::rect(X[i],Y[i]-fact*sY[i],X[i+1],Y[i]+fact*sY[i],col=colour[i])
         if (i<ns) graphics::lines(rep(X[i+1],2),c(Y[i]-fact*sY[i],Y[i+1]+fact*sY[i+1]))
     }
-    if (plateau & title) title(plateau.title(plat,sigdig=sigdig))
+    if (plateau & title) graphics::title(plateau.title(plat,sigdig=sigdig))
     else return(plat)
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka `inherited',
@@ -109,7 +110,7 @@ agespectrum.ArAr <- function(x,alpha=0.05,plateau=TRUE,
     # taking into account decay and J uncertainties
     plat$mean <- get.ArAr.age(R[1],R[2],x$J[1],x$J[2],exterr=exterr)
     if (plateau){
-        title(plateau.title(plat,sigdig=sigdig))
+        graphics::title(plateau.title(plat,sigdig=sigdig))
     }
 }
 
