@@ -28,7 +28,6 @@
 #' intercept, and standard errors of the best straight line."
 #' American Journal of Physics 72.3 (2004): 367-375.
 #'
-#' @importFrom stats lm
 #' @examples
 #'    X <- c(1.550,12.395,20.445,20.435,20.610,24.900,
 #'           28.530,50.540,51.595,86.51,106.40,157.35)
@@ -53,7 +52,7 @@
 #' @export
 york <- function(x){
     colnames(x) <- c('X','sX','Y','sY','rXY')
-    ab <- lm(x[,'Y'] ~ x[,'X'])$coefficients # initial guess
+    ab <- stats::lm(x[,'Y'] ~ x[,'X'])$coefficients # initial guess
     a <- ab[1]
     b <- ab[2]
     wX <- 1/x[,'sX']^2
@@ -98,7 +97,7 @@ get.york.mswd <- function(x,a,b){
     df <- (2*nn-2)
     out <- list()
     out$mswd <- as.numeric(X2/df)
-    out$p.value <- as.numeric(1-pchisq(X2,df))
+    out$p.value <- as.numeric(1-stats::pchisq(X2,df))
     out
 }
 
@@ -126,10 +125,10 @@ data2york.UPb <- function(x,wetherill=TRUE,...){
     out <- matrix(0,ns,5)
     colnames(out) <- c('X','sX','Y','sY','rXY')
     if (wetherill){
-        if (x$format==1 | x$format==3){
+        if (x$format %in% c(1,3,4)){
             out <- x$x[,c('Pb207U235','errPb207U235',
                           'Pb206U238','errPb206U238','rhoXY')]
-        } else if (x$format==2){
+        } else if (x$format %in% c(2,5,6)){
             for (i in 1:ns){
                 samp <- wetherill(x,i=i,exterr=FALSE)
                 out[i,1] <- samp$x['Pb207U235']
@@ -140,10 +139,10 @@ data2york.UPb <- function(x,wetherill=TRUE,...){
             }
         }
     } else {
-        if (x$format==2){
+        if (x$format %in% c(2,5)){
             out <- x$x[,c('U238Pb206','errU238Pb206',
                           'Pb207Pb206','errPb207Pb206','rhoXY')]
-        } else if (x$format==1 | x$format==3){
+        } else if (x$format %in% c(1,3,4,6)){
             for (i in 1:ns){
                 samp <- tera.wasserburg(x,i=i,exterr=FALSE)
                 out[i,1] <- samp$x['U238Pb206']
